# encoding: utf-8

class PhotoUploader < CarrierWave::Uploader::Base
#   before :store, :extract_image_info

  # Include RMagick or MiniMagick support:
#   include CarrierWave::RMagick
  include CarrierWave::MiniMagick

  # Choose what kind of storage to use for this uploader:
  storage :file
  # storage :fog

  # Override the directory where uploaded files will be stored.
  # This is a sensible default for uploaders that are meant to be mounted:
  def store_dir; "photo_uploads"  end
  def cache_dir; "tmp/uploader"  end

  # Provide a default URL as a default if there hasn't been a file uploaded:
  # def default_url
  #   # For Rails 3.1+ asset pipeline compatibility:
  #   # ActionController::Base.helpers.asset_path("fallback/" + [version_name, "default.png"].compact.join('_'))
  #
  #   "/images/fallback/" + [version_name, "default.png"].compact.join('_')
  # end

  # Process files as they are uploaded:
  # process :scale => [200, 300]
  #
  # def scale(width, height)
  #   # do something
  # end
  
  process :rotate_and_extract_image_info
  
  # Create different versions of your uploaded files:
  version :medium do
    process :resize_to_limit => [1000, 1000]
  end
  version :thumb do
    process :resize_to_limit => [225, 225]
  end

  # Add a white list of extensions which are allowed to be uploaded.
  # For images you might use something like this:
  def extension_white_list
    %w(jpg jpeg)
  end

  # Override the filename of the uploaded files:
  # Avoid using model.id or version_name here, see uploader/store.rb for details.
  def filename
    old_filename = File.basename(model.image.andand.file.andand.file.to_s)
    
    if old_filename.blank?
      DateTime.now.strftime("%y%m%d-%H%M%S") + '.' + file.extension
    else
      old_filename
    end
  end
  
  def rotate_and_extract_image_info(*args)
    # store original filename
    model.original_filename ||= file.original_filename if file.respond_to?(:original_filename)
    
    manipulate! do |img|
      img.auto_orient
    end
  
    # get coordinates from EXIF
    EXIFR::JPEG.new(file.to_file).gps.tap do |gps|
      model.lat = gps.andand.latitude
      model.lon = gps.andand.longitude
      model.vyska = gps.andand.altitude
      model.image_direction = gps.andand.image_direction
#       raise model.lat.inspect
    end
  end
end

#  lat: 50.435539444444444, lon: 16.039459444444443, vyska: nil, image_direction: 331.22>
